@@ -1,9 +1,9 @@
 var a00212 =
 [
     [ "osl::Mutex", "a00814.html", "a00814" ],
-    [ "osl::Guard< T >", "a00818.html", "a00818" ],
-    [ "osl::ClearableGuard< T >", "a00822.html", "a00822" ],
-    [ "osl::ResettableGuard< T >", "a00826.html", "a00826" ],
+    [ "osl::Guard&lt; T &gt;", "a00818.html", "a00818" ],
+    [ "osl::ClearableGuard&lt; T &gt;", "a00822.html", "a00822" ],
+    [ "osl::ResettableGuard&lt; T &gt;", "a00826.html", "a00826" ],
     [ "osl::ClearableMutexGuard", "a00530.html#a6e908d0f1f872669f693546260a9bac1", null ],
     [ "osl::MutexGuard", "a00530.html#a79aaaf4cd921a2a28d75d96ae760095c", null ],
     [ "osl::ResettableMutexGuard", "a00530.html#a950a2595531607f91b8654d4fbb4aa8d", null ]
