@@ -3,8 +3,8 @@ var a00410 =
     [ "cppu::detail::element_alias", "a01854.html", "a01854" ],
     [ "cppu::OInterfaceIteratorHelper", "a01858.html", "a01858" ],
     [ "cppu::OInterfaceContainerHelper", "a01862.html", "a01862" ],
-    [ "cppu::OMultiTypeInterfaceContainerHelperVar< key, hashImpl, equalImpl >", "a01870.html", "a01870" ],
-    [ "cppu::OBroadcastHelperVar< container, keyType >", "a01874.html", "a01874" ],
+    [ "cppu::OMultiTypeInterfaceContainerHelperVar&lt; key, hashImpl, equalImpl &gt;", "a01870.html", "a01870" ],
+    [ "cppu::OBroadcastHelperVar&lt; container, keyType &gt;", "a01874.html", "a01874" ],
     [ "cppu::hashType_Impl", "a01878.html", "a01878" ],
     [ "cppu::OMultiTypeInterfaceContainerHelper", "a01882.html", "a01882" ],
     [ "cppu::OBroadcastHelper", "a00537.html#a6d440e234745b9ec908f615324b88398", null ]
